@@ -1,8 +1,8 @@
 # Load necessary libraries
 library(testthat)
 library(SUMO)  # Load your package
-#output_sim <- OmixCraftHD(vector_features = c(2000,3000), sigmas_vector=c(4,5), n_samples=100, n_factors=5, num.factor='multiple', advanced_dist='mixed')
- output_obj <- OmixCraftHD(
+#output_sim <- simulate_twoOmicsData(vector_features = c(2000,3000), sigmas_vector=c(4,5), n_samples=100, n_factors=5, num.factor='multiple', advanced_dist='mixed')
+ output_obj <- simulate_twoOmicsData(
    vector_features = c(4000,3000),
    n_samples=100,
    n_factors=2,
